# Copyright (c) 2000-2005, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

# To build with dom4j issue rpmbuild --with dom4j xom.spec

%define with_dom4j %{?_with_dom4j:1}%{!?_with_dom4j:0}
%define without_dom4j %{!?_with_dom4j:1}%{?_with_dom4j:0}

Summary:        XML Object Model
Name:           xom
Version:        1.2.10
Release:        6%{?dist}
Epoch:          0
License:        LGPLv2
URL:            http://www.xom.nu
Source0:        http://www.cafeconleche.org/XOM/%{name}-%{version}-src.tar.gz

# Don't download jaxen, set javac target/source to 1.5
Patch0:         %{name}-build.patch

BuildRequires:  ant >= 0:1.6
BuildRequires:  javapackages-local
BuildRequires:  javapackages-tools
BuildRequires:  jarjar
BuildRequires:  jaxen
BuildRequires:  junit
BuildRequires:  xalan-j2
BuildRequires:  xerces-j2
%if %{with_dom4j}
BuildRequires:  dom4j
%endif
BuildRequires:  xml-commons-apis
BuildRequires:  tagsoup
# Use JAXP implementation in JDK
BuildRequires:  java-devel
BuildRequires:  xml-commons-resolver
BuildRequires:  servlet

Requires:  jaxen
Requires:  xalan-j2
Requires:  xerces-j2
Requires:  xml-commons-apis

BuildArch: noarch


%description
XOM is a new XML object model. It is an open source (LGPL),
tree-based API for processing XML with Java that strives
for correctness, simplicity, and performance, in that order.
XOM is designed to be easy to learn and easy to use. It
works very straight-forwardly, and has a very shallow
learning curve. Assuming you're already familiar with XML,
you should be able to get up and running with XOM very quickly.

%package javadoc
Summary:        API documentation for %{name}

%description javadoc
This package provides %{summary}.

%package demo
Summary:        Samples for %{name}
Requires:       %{name} = %{version}-%{release}

%description demo
This package provides %{summary}.

%prep
%setup -q -n XOM

%patch0 -p1

# fix non ASCII chars
for s in src/nu/xom/tests/BuilderTest.java\
 src/nu/xom/tests/SerializerTest.java;do
  native2ascii -encoding UTF8 ${s} ${s}
done

# Fix encoding
sed -i 's/\r//g' LICENSE.txt
sed -i "s,59 Temple Place,51 Franklin Street,;s,Suite 330,Fifth Floor,;s,02111-1307,02110-1301,"  $(find -name "*.java") \
 LICENSE.txt lgpl.txt

%build
mkdir -p lib
pushd lib
ln -sf $(build-classpath junit) junit.jar
ln -sf $(build-classpath xerces-j2) dtd-xercesImpl.jar
ln -sf $(build-classpath xalan-j2) xalan.jar
ln -sf $(build-classpath xml-commons-apis) xmlParserAPIs.jar
ln -sf $(build-classpath jaxen) jaxen.jar

# jarjar has more than one jars
while IFS=':' read -ra JARJAR_JARS; do 
    for j in "${JARJAR_JARS[@]}";do 
        ln -sf $j $(basename $j .jar)-1.0.jar
    done
done <<<$(build-classpath jarjar)
popd
mkdir -p lib2
pushd lib2
ln -sf $(build-classpath tagsoup) tagsoup-1.2.jar
ln -sf $(build-classpath xml-commons-resolver) resolver.jar

%if %{with_dom4j}
ln -sf $(build-classpath dom4j) dom4j.jar
%endif

ln -sf $(build-classpath servlet) servlet.jar
popd

ant -v compile15 jar samples betterdoc maven2

pushd build/apidocs
for f in `find -name \*.css -o -name \*.html`; do
  sed -i 's/\r//g' $f
done
popd

mv build/maven2/project.xml build/maven2/pom.xml
%pom_add_dep jaxen:jaxen build/maven2/pom.xml
%mvn_artifact build/maven2/pom.xml build/%{name}-%{version}.jar
%mvn_alias xom:xom com.io7m.xom:xom

%install
%mvn_install
# For compatibility
# jars
ln -s xom/%{name}.jar %{buildroot}%{_javadir}/%{name}.jar
#install -d -m 755 %{buildroot}%{_javadir}
#install -m 644 build/%{name}-%{version}.jar \
#  %{buildroot}%{_javadir}/%{name}.jar

# javadoc
install -d -m 755 %{buildroot}%{_javadocdir}/%{name}
cp -pr build/apidocs/* %{buildroot}%{_javadocdir}/%{name}

# demo
install -d -m 755 %{buildroot}%{_datadir}/%{name}
install -m 644 build/xom-samples.jar %{buildroot}%{_datadir}/%{name}

# POM
install -d -m 755 %{buildroot}%{_mavenpomdir}
ln -s xom/xom.pom %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
#install -m 644 build/maven2/pom.xml %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
#%add_maven_1depmap JPP-%{name}.pom %{name}.jar

%files -f .mfiles
%doc README.txt
%doc LICENSE.txt
%doc Todo.txt
%doc lgpl.txt
%{_javadir}/%{name}.jar
%{_mavenpomdir}/JPP-%{name}.pom

%files javadoc
%{_javadocdir}/%{name}
%doc LICENSE.txt
%doc lgpl.txt

%files demo
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/xom-samples.jar

%changelog
* Fri Feb 26 2016 Ding-Yi Chen <dchen@redhat.com> - 0:1.2.10-6
- Use the "real" xom-1.2.10
- mvn_alias to group ID com.io7m.xom

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0:1.2.10-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Oct 20 2015 Ding-Yi Chen <dchen@redhat.com> - 0:1.2.10-4
- Fix the build to handle multiple jars in jarjar.

* Tue Jun 23 2015 Michal Srb <msrb@redhat.com> - 0:1.2.10-3
- Depend on pristine jaxen classes

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.2.10-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Mar 24 2015 Michal Srb <msrb@redhat.com> - 0:1.2.10-1
- Update to latest upstream version 1.2.10
- Spec file clean up

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.0-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Jan 23 2014 Mikolaj Izdebski <mizdebsk@redhat.com> - 0:1.0-15
- Update to current packaging guidelines
- Remove versioned JARs, resolves: rhbz#1022173
- Add workaround for rhbz#646523

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.0-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Jun 28 2013 Mikolaj Izdebski <mizdebsk@redhat.com> - 0:1.0-13
- Replace BR on libgcj with generic java-devel

* Fri Feb 15 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.0-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Tue Nov 27 2012 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0:1.0-11
- Remove icu4j dependency from pom.xml

* Mon Oct  8 2012 Mikolaj Izdebski <mizdebsk@redhat.com> - 0:1.0-10
- Replace icu4j Normalizer with java.text.Normalizer from JDK

* Fri Aug 10 2012 Andy Grimm <agrimm@gmail.com> - 0:1.0-9
- add POM

* Sun Jul 22 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.0-8.6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.0-7.6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.0-6.6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Mar 11 2010 Peter Lemenkov <lemenkov@gmail.com> - 0:1.0-5.6
- Added missing Requires: jpackage-utils (%%{_javadir} and %%{_javadocdir})

* Mon Jul 27 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.0-5.5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.0-4.5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Jul 10 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0:1.0-3.5
- drop repotag
- fix license tag

* Mon Mar 26 2007 Nuno Santos <nsantos@redhat.com> 0:1.0-3jpp.4.fc7
- Apply patch from bugs.michael@gmx.net to fix unowned directory

* Mon Mar 12 2007 Vivek Lakshmanan <vivekl@redhat.com> 0:1.0-3jpp.3.fc7
- Make build with dom4j optional (off by default)

* Mon Mar 12 2007 Vivek Lakshmanan <vivekl@redhat.com> 0:1.0-3jpp.2.fc7
- Remove BR on classpathx-jaxp since libgcj includes the required bits

* Wed Feb 14 2007 Andrew Overholt <overholt@redhat.com> 0:1.0-3jpp.1
- Update for Fedora review
- Remov Vendor & Distribution tags
- Add .1%%{?dist} to release
- Remove bad javadoc symlinking and %%post{,un}
- Fixe buildroot
- Use %%doc for doc files
- Change group to Development/Libraries
- Remove running of tests; should perhaps move to %%check
- Fix encoding of LICENSE.txt and generated javadocs
- Remove BR: saxon

* Tue Feb 28 2006 Fernando Nasser <fnasser@redhat.com> - 0:1.0-3jpp
- Remove dependency on clover10 (non-free)

* Sun Feb 26 2006 Fernando Nasser <fnasser@redhat.com> - 0:1.0-2jpp
- First JPP 1.7 release

* Wed Aug 17 2005 Ralph Apel <r.apel at r-apel.de> - 0:1.0-1jpp
- First JPP release
